#
# spec file for package etcd-for-k8s1.29
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project go.etcd.io/etcd

Name:           etcd-for-k8s1.29
Version:        3.5.16
Release:        1.1
Summary:        Etcd and etcdtl for k8s image
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/etcd-io/etcd
Source:         etcd-%{version}.tar.gz
Source1:        vendor-etcdctl.tar.gz
Source2:        vendor-server.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.22
ExcludeArch:    %ix86
ExcludeArch:    s390
Conflicts:      etcd
Conflicts:      etcdctl
Provides:       etcd-for-k8s = %{version}
Conflicts:      etcd-for-k8s

%description
etcd is a distributed, consistent key-value store for shared configuration and
service discovery. This package contains different versions of etcd and
etcdctl for the kubernetes container image.

%prep
%setup -q -n etcd-%{version}

%build
%{goprep} %{project}

tar -xf %{SOURCE1} -C ./etcdctl
tar -xf %{SOURCE2} -C ./server

mkdir ./bin

cd ./etcdctl
go build -v -buildmode=pie -mod=vendor -o ../bin/etcdctl
cd ..

cd ./server
go build -v -buildmode=pie -mod=vendor -o ../bin/etcd
cd ..

%install
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_sbindir}
install -D -p -m 0755 bin/etcdctl %{buildroot}%{_bindir}/etcdctl-%{version}
install -D -p -m 0755 bin/etcd %{buildroot}%{_sbindir}/etcd-%{version}

ln -sf etcdctl-%{version} %{buildroot}%{_bindir}/etcdctl
# ln -sf etcd-%{version} %{buildroot}%{_sbindir}/etcd
# we need a wrapper script to be able to set some environment variables.
echo "#!/bin/bash" > %{buildroot}%{_sbindir}/etcd
%ifarch aarch64
echo "export ETCD_UNSUPPORTED_ARCH=arm64" >> %{buildroot}%{_sbindir}/etcd
%endif
echo "exec %{_sbindir}/etcd-%{version} \"\$@\"" >> %{buildroot}%{_sbindir}/etcd
chmod 755 %{buildroot}%{_sbindir}/etcd

%files
%defattr(-,root,root)
%license LICENSE
%{_sbindir}/etcd
%{_sbindir}/etcd-%{version}
%{_bindir}/etcdctl
%{_bindir}/etcdctl-%{version}

%changelog
* Thu Nov 28 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.16:
  * Backport TestLessorRenewExtendPileup race condition fix for release-3.5
  * Bump go toolchain to 1.22.7
  * Introduce compaction sleep interval flag
  * Fix passing default grpc call options in Kubernetes client
  * bump bbolt to 1.3.11 for 3.5
  * tests/e2e: add test cases related to HashKV
  * *: keep tombstone if revision == compactAtRev
  * *: update tests for watch API when compact on tombstone revision
  * mvcc/*_test.go: should not use duplicate revision.Main for one key
  * client/pkg/testutil: update interestingGoroutines
  * tests/e2e: add e2e test to reproduce issue 18089
  * test: extend leaseRevoke and leaseRenew test to support 5 members cluster
  * Skip leadership check if the etcd instance is active processing heartbeats
  * Backport setting default read-only permissions.
  * Complete backport of migration to OWNERS file.
  * Cleanup github.com/etcd-io/gofail
  * Upgrade gofail to v0.2.0
  * Backport migration of OWNERS file.
  * build(deps): bump distroless/static-debian11 from `6d31326` to `1dbe426`
  * Introduce Kubernetes KV interface to etcd client
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  golang(API) >= 1.22`
  * ref: https://github.com/etcd-io/etcd/blob/v3.5.16/go.mod#L3-L5
* Thu Oct 10 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.15:
  * Differentiate the warning message for rejected client and peer connections
  * client/v3/watch_test.go: test fmt metadata print
  * client/v3/watch.go: use fmt for metadata printing
  * Backport: fix(server/embed): enforce non-empty client TLS if scheme is https/unixs
  * fix ts with no trailing zeros
  * Remove gsutil acl command for bucket permissions.
  * dependency: bump tools/mod google.golang.org/genproto
  * dependency: bump tools/mod github.com/spf13/cobra to v1.1.3
  * dependency: bump tools/mod github.com/olekukonko/tablewriter to v0.0.5
  * dependency: bump tools/mod github.com/mattn/go-runewidth
  * dependency: bump tools/mod github.com/mattn/go-colorable
  * dependency: bump tools/mod github.com/grpc-ecosystem/grpc-gateway
  * make: Include tools/mod when checking dependency versions
  * Bump Go version to 1.21.12: GO-2024-2963 fix
  * Suppress noisy basic auth token deletion log
  * github/govuln: don't swallow govulncheck errors
  * tests/integration: deflake TestV3AuthWithLeaseRevokeWithRootJWT
  * etcd 3.5: Install shellcheck if not installed.
  * dependency: dump golang.org/x/sys to the highest version v0.18.0
  * dependency: bump github.com/modern-go/concurrent to the highest version v0.0.0-20180306012644-bacd9c7ef1dd
  * dependency: bump github.com/google/go-cmp to the highest version v0.6.0
  * Fix dependency inconsistency detection and add make verify-dep
  * dependency: bump golang.org/x/sys from v0.0.0-20210403161142-5e06dd20ab57 to v0.0.0-20220412211240-33da011f77ad
  * dependency: bump golang.org/x/net from 0.17.0 to 0.23.0
  * Fix govulncheck CI check on release-3.5
  * bugfix: register of walWriteSec
  * Support multiple values for allowed client and peer TLS identities(#18015)
  * print error log when validation on conf change failed
  * scripts/release: shallow clone repository
  * Backport removal of asset transparency workflow.
  * config: support AllowedCN and AllowedHostname through config file
  * scripts: default to using .go-version's version for tests and builds
  * .*: sync go toolchain version and add ability to verify versions
  * etcdutl: Fix snapshot restore memory alloc issue
  * server: Implement WithMmapSize option for backend config
  * Add cluster downgrade test.
  * Bump bbolt to 1.3.10 for 3.5
  * v3rpc: run health notifier to listen on online defrag state change
  * build(deps): bump distroless/static-debian11 from `046b92c` to `6d31326`
  * gRPC health server sets serving status to NOT_SERVING on defrag
  * e2e: add mix version test of adding last ver to current ver.
  * server/mvcc: should update currentRev in revMu
  * server/storage: update currentRev if scheduledCompact > currentRev
  * tests/e2e: reproduce #17780
  * server/mvcc: introduce compactBeforeSetFinishedCompact failpoint
  * Update the compaction log when bootstrap and update compact's signature
  * test: add checking snapshot be sent in mix_version_test.
  * [backport-3.5] server: ignore raft messages if member id mismatch #17078
  * add experimental-snapshot-catchup-entries flag.
  * test: add mix version e2e test.
  * feat: observe wal write at one time
  * Add approvals gh workflows.
  * [3.5]Add trivy scan as a job in release workflow
  * *: LeaseTimeToLive returns error if leader changed
  * .github: enable failpoints for integration tests
  * Bump golang.org/x/net to v0.23.0
  * Backport initialization of mu in NewCtxClient to release-3.5
  * Backport updates to shellcheck ignores for release.sh script.
  * Backport rename of release script to release.sh.
  * Backport update for release script to use ssh.
  * build(deps): bump distroless/static-debian11 from `7e5c6a2` to `046b92c`
  * Fix retry requests when receiving ErrGPRCNotSupportedForLearner
  * build(deps): bump distroless/static-debian11 from `9be3fcc` to `7e5c6a2`
  * [release-3.5] backport fix watch event loss after compaction
  * Fix progress notification for watch that doesn't get any events
  * Add govuln GitHub workflow
  * dependency: bump google.golang.org/protobuf to v1.33.0
  * dependency: bump github.com/sirupsen/logrus to v1.9.3
  * add uds test cases into e2e TestAuthority
  * Add unix socket test to TestNewURLsValue
  * pkg/types: Support Unix sockets in NewURLS
  * added dial-keepalive-time、dial-keepalive-timeout、permit-without-stream arguments to the grpc-proxy
  * Backport ignore old leader's leases revoking request
  * tests/e2e: backport e2e cluster setup
  * *: add test-smoke to the pipeline and update test-smoke
  * tools/mod: go mod tidy
  * *: fix failing shellchecks
  * server: fix comment to match function name
  * tests/e2e: implement EtcdProcess GoFailClientTimeout
  * Make CGO_ENABLED configurable for etcd 3.5
  * tests/e2e: use WaitLeader in corrupt test
  * tests/e2e: implement EtcdProcessCluster WaitLeader
  * tests/e2e: implement EtcdProcess Etcdctl
  * etcd: Add OpenBSD-specific files for SetKeepAlivePeriod handling
  * etcdserver: drain leaky goroutines before test completed
  * tests/e2e: move etcdctl to framework/e2e
  * [3.5] backport: add backoff to client config
* Mon Apr  8 2024 priyanka.saggu@suse.com
- Update to version 3.5.12:
  * Bump golang.org/x/crypto to v0.17+ to address CVE-2023-48795
  * test: fix TestHashKVWhenCompacting: ensure all goroutine finished
  * print error log when creating peer listener failed
  * mvcc: Printing etcd backend database related metrics inside scheduleCompaction function
  * dependency: update go version to 1.20.13
  * commit bbolt transaction if there is any pending deleting operations
  * add tests to test tx delete consistency.
  * Don't flock snapshot files
  * Backport adding digest for etcd base image.
  * Add a unit tests and missing flags in etcd help.
  * Add missing flag in etcd help.
  * Backport testutils.ExecuteUntil to 3.5 branch
  * member replace e2e test
  * Check if be is nil to avoid panic when be is overriden with nil by recoverSnapshotBackend on line 517
  * Don't redeclare err and snapshot variable, fixing validation of consistent index and closing database on defer
  * test: enable gofail in release e2e test.
  * [3.5] backport health check e2e tests.
  * etcdserver: add linearizable_read check to readyz.
  * etcd: Update go version to 1.20.12
  * tests: Extract e2e cluster setup to separate package
  * server: disable redirects in peer communication
  * etcdserver: add metric counters for livez/readyz health checks.
  * etcdserver: add livez and ready http endpoints for etcd.
  * http health check bug fixes
  * server: Split metrics and health code
  * server: Cover V3 health with tests
  * server: Refactor health checks
  * server: Run health check tests in subtests
  * server: Rename test case expect fields
  * server: Use named struct initialization in healthcheck test
  * Backport server: Don't follow redirects when checking peer urls.
  * Backport embed: Add tracing integration test.
  * Backport server: Have tracingExporter own resources it initialises.
  * Backport server: Add sampling rate to distributed tracing.
  * upgrade github.com/stretchr/testify,google.golang.org/genproto/googleapis/api,google.golang.org/grpc to make it consistent
  * CVE-2023-47108: Backport go.opentelemetry.io/otel@v1.20.0 and go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc@v0.46.0
  * github workflow: run arm64 tests on every push
  * etcd: upgrade go version from 1.20.10 to 1.20.11
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.10:
  * bump bbolt to 1.3.8 for etcd 3.5
  * 3.5: upgrade gRPC-go to 1.58.3
  * Backport corrupt check test fix "etcd server shouldn't wait for the ready notification infinitely on startup"
  * etcdserver: add cluster id check for hashKVHandler
  * [release-3.5]: upgrade gRPC-go to v1.52.0
  * backport #14125 to release-3.5: Update to grpc-1.47 (and fix the connection-string format)
  * Return to default write scheduler since golang.org/x/net@v0.11.0 started using round robin
  * Bump go to v1.20.10 Part of https://github.com/etcd-io/etcd/issues/16740
  * bump golang.org/x/net to 0.17.0 Part of https://github.com/etcd-io/etcd/issues/16740
  * etcd: upgrade go version to 1.20.9
  * Remove obsolete http 1.0 version.
  * fix:Ensure that go version is only defined in one file for release-3.5
  * Fix panic in etcd validate secure endpoints
  * Backport redirect metrics data into file to reduce output.
  * test.sh: increase timeout for grpcproxy test
  * test: add v3 curl test to cover maintenance hash/hashkv REST API
  * api: fix duplicate gateway url issue
  * pkg: add a verification on the pagebytes which must be > 0
  * tests: Backport deflake for TestWatchDelay
  * tests: Backport deflake for TestPageWriterRandom
  * Backport adding unit test for socket options.
  * Backport export reuse-port and reuse-address
  * Fix goword failure in rafthttp/transport.go.
  * Backport update to golang 1.20 minor release.
  * Update workflows to use makefile recipes for unit, integration & e2e-release.
  * Backport Makefile recipes for common test commands.
  * pkg/flags: fix UniqueURLs'Set to remove duplicates in UniqueURLs'uss
  * Backport fix to e2e release version identifcation.
  * Backport #14368 to v3.5
  * Follow up https://github.com/etcd-io/etcd/pull/16068#discussion_r1263667496
  * etcdserver: backport check scheduledCompactKeyName and finishedCompactKeyName before writing hash to release-3.5.
  * Backport #13577 Disable auth gracefully without impacting existing watchers.
  * bump go version to 1.19.11 to fix CVE GO-2023-1878
  * clientv3: create keepAliveCtxCloser goroutine only if ctx can be canceled
  * [3.5] etcdutl: fix db double closed
  * clientv3: remove v3.WithFirstKey() in Barrier.Wait()
  * update etcdctl flag description for snapshot restores
  * etcdutl: update description for --mark-compacted and --bump-revision flags in snapshot restore command
  * Adding optional revision bump and mark compacted to snapshot restore
  * Revert "Merge pull request #16119 from natusameer/release-3.5"
  * Add e2e-arm64.yaml and tests-arm64.yaml to release-3.5 scheduled at 1.30
  * Backport .github/workflows: Read .go-version as a step and not separate workflow.
  * Add first unit test for authApplierV3
  * Early exit auth check on lease puts
  * remove stack log when etcdutl restore
  * etcdserver: fix corruption check when server has just been compacted
  * replace gobin with go install
  * [3.5] Backport updating go to latest patch release 1.19.10
  * add compact hash check to help
  * Fix test of clientv3/naming
  * clientv3/naming/endpoints: fix endpoints prefix bug fixes bug with multiple endpoints with same prefix
  * grpcproxy: fix memberlist results not update when proxy node down
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Initial package version 3.5.10:
  * Version specified in kubernetes v1.29.1 https://github.com/kubernetes/kubernetes/blob/v1.29.1/build/dependencies.yaml#L65
